[gnome-shell] osdWindow: bump down the OSD window size a bit
- From: Cosimo Cecchi <cosimoc src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gnome-shell] osdWindow: bump down the OSD window size a bit
- Date: Thu, 7 Mar 2013 22:02:59 +0000 (UTC)
commit ce5faba18589a26a995de2ca5f2b7f37eb5326db
Author: Cosimo Cecchi <cosimoc gnome org>
Date: Thu Mar 7 16:45:50 2013 -0500
osdWindow: bump down the OSD window size a bit
Matches what this commit did for g-s-d:
https://git.gnome.org/browse/gnome-settings-daemon/commit/plugins/media-keys?id=fbf3c5aa366ef7212f209e123d4aae315a1a2a8e
https://bugzilla.gnome.org/show_bug.cgi?id=695409
js/ui/osdWindow.js | 4 ++--
1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/js/ui/osdWindow.js b/js/ui/osdWindow.js
index efcd10d..b25c0aa 100644
--- a/js/ui/osdWindow.js
+++ b/js/ui/osdWindow.js
@@ -164,12 +164,12 @@ const OsdWindow = new Lang.Class({
},
_monitorsChanged: function() {
/* assume 130x130 on a 640x480 display and scale from there */
let monitor = Main.layoutManager.primaryMonitor;
let scalew = monitor.width / 640.0;
let scaleh = monitor.height / 480.0;
let scale = Math.min(scalew, scaleh);
- let size = 130 * Math.max(1, scale);
+ let size = 110 * Math.max(1, scale);
this._box.set_size(size, size);
this._box.translation_y = monitor.height / 4;
[
@@ -164,12 +164,12 @@ const OsdWindow = new Lang.Class({
},
_monitorsChanged: function() {
- /* assume 130x130 on a 640x480 display and scale from there */
+ /* assume 110x110 on a 640x480 display and scale from there */
let monitor = Main.layoutManager.primaryMonitor;
let scalew = monitor.width / 640.0;
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]